//
// PDBSort.h
//
// This file contains declarations for the PDBSort class.
//
// These classes are part of the Bioinformatics Template Library (BTL).
//
// Copyright (C) 1997,1998 Birkbeck College, Malet Street, London WC1E 7HX, U.K.
// (classlib@mail.cryst.bbk.ac.uk)
// 
// This library is free software; you can
// redistribute it and/or modify it under the terms of
// the GNU Library General Public License as published by the Free
// Software Foundation; either version 2 of the License, or (at your
// option) any later version.  This library is distributed in the hope
// that it will be useful, but WITHOUT ANY WARRANTY; without even the
// implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
// PURPOSE.  See the GNU Library General Public License for more details.
// You should have received a copy of the GNU Library General Public
// License along with this library; if not, write to the Free Software
// Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
///////////////////////////////////////////////////////////////////////////

#if !defined(BTL_PDBSORT_H)
#define BTL_PDBSORT_H

#if !defined(SGI_CC)
#include <string>
#include <vector>
#else
#include <mstring.h>
#include <vector.h>
#endif

#include "btl/BTL.h"

#if !defined(SGI_CC) && !defined(GCC_272)
using namespace std;
#endif

/**#: [Description ="
     This class defines a functor or function object which can be used by
     a generic sort routine to sort atoms into the order used in 
     Brookhaven pdb format files. Order is defined by strings, 2 or 3 
     characters long."]
      [Summary = "function object (functor) used for sorting objects into
      Brookhaven Protein Data Bank (pdb) format atom order"] 
    [Authors = "W.R.Pitt"]
    [Files = "<A HREF=./btl/PDBSort.h>PDBSort.h</A>,
              <A HREF=./btl/PDBSort.cpp>PDBSort.cpp</A>"]
    [Dependencies="none"]

*/

class BTL_PDBSort
{

private:

    static const short  ATOMMAX;

    static const string ATOMNAME[68];

	    	/**#: [Hidden] */
    bool    
    EqualsAtomName(const string atomId, const short nameIdx) const;
    	    
	    	/**#: [Hidden] */
    short   
    FindIndx(const string& atomId1) const;    

public:

	    	/**#: [Description="Returns true is 1st string comes before
	    	       the 2nd in pdb order. Returns false otherwise"] */
    bool    operator()(const string& atomId1, const string& atomId2) const;

	    	/**#: [Description="The c style string version of the above
	    	       function"] */
    bool    operator()(const char* atomId1, const char* atomId2) const;
    	    	
};
   	    	        	    	        	    	 
#endif  // PDBSort.h
